@@ -1,6 +1,6 @@
 package Beam::Emitter;
 # ABSTRACT: Role for event emitting classes
-$Beam::Emitter::VERSION = '0.008';
+$Beam::Emitter::VERSION = '1.000';
 use strict;
 use warnings;
 
@@ -10,7 +10,8 @@ use Scalar::Util qw( refaddr );
 use Carp qw( croak );
 use Beam::Event;
 
-
+# The event listeners on this object, a hashref of arrayrefs of
+# EVENT_NAME => [ CALLBACK, ... ]
 has _listeners => (
     is      => 'ro',
     isa     => HashRef,
@@ -83,7 +84,7 @@ Beam::Emitter - Role for event emitting classes
 
 =head1 VERSION
 
-version 0.008
+version 1.000
 
 =head1 SYNOPSIS
 
@@ -125,11 +126,11 @@ processed, or prevent the default action from happening.
 =head2 Using Beam::Event
 
 L<Beam::Event> is an event object with some simple methods to allow subscribers
-to influence the handling of the event. By calling the L<stop|Beam::Event/stop>
-method, subscribers can stop all futher handling of the event. By calling the
-L<stop_default|Beam::Event/stop_default>, subscribers can allow other subscribers
-to be notified about the event, but let the emitter know that it shouldn't
-continue with what it was going to do.
+to influence the handling of the event. By calling L<the stop
+method|Beam::Event/stop>, subscribers can stop all futher handling of the
+event. By calling the L<the stop_default method|Beam::Event/stop_default>,
+subscribers can allow other subscribers to be notified about the event, but let
+the emitter know that it shouldn't continue with what it was going to do.
 
 For example, let's build a door that notifies when someone tries to open it.
 Different instances of a door should allow different checks before the door
@@ -242,12 +243,6 @@ instead of L<emit> to give arbitrary arguments to your listeners.
 There's no way to stop the door being opened, but you can at least notify
 someone before it does.
 
-=head1 ATTRIBUTES
-
-=head2 _listeners
-
-The event listeners registered on this object.
-
 =head1 METHODS
 
 =head2 subscribe ( event_name, subref )
